#!/usr/bin/env python
# coding: utf-8

# ### 2.2 accessing specific parts of the data
# 
# One can access a column just by using `df[<column name>]` :


import pandas as pd

df = pd.read_table( "data_files/class.tsv" )
print(df.head())


# Remember you can easily select a single column from the DataFrame
print( df['Weight'] )


# To access a **specific section of the data, use the `.loc[ : , : ]` operator.**
# It takes two slicing arguments that, respectively, targets rows and columns. A `:` selects all elements.

print( df.loc[ 0:3 , : ] ) ### first 3 rows, all columns





print( df.loc[ 0:3 , ['Gender' , 'Height' ] ] ) ### first 3 rows, columns 'Gender' and 'Height'




print( df.loc[ : , 'Age' ] ) ### all rows, column 'Age'



# You can also access a subset of the data using conditions on the values.
# To do so, the first step is to create a mask, which will then be applied to the data.
# Here is an example of the creation of a mask to select rows where the Age is above 14 :

maskAge = df['Age' ] > 14 # Age should be above 14
print( maskAge.value_counts() )


# The mask (in fact a `pandas.core.series.Series`), is in effect a list of values that are ```True``` or `False` depending on whether or not they satisfy the defined condition (Age is above 14, here).
# 
# The mask can then be applied to the `DataFrame`.


print( df.loc[ maskAge  , ['Age','Height','Weight'] ] )


# Masks may be combined to produce more complex selection criteria, using **`&`** (logical and) and **`|`** (logical or).

# rows with Age above 14 and Gender is F
mask = (df[ 'Age' ] > 14 ) & ( df[ 'Gender' ] == 'F' ) 

print( df.loc[ mask , ] )


